__all__ = [
    "AccessibleBiddingStrategy",
    "AccountBudget",
    "AccountBudgetProposal",
    "AccountLink",
    "Ad",
    "AdGroup",
    "AdGroupAd",
    "AdGroupAdAssetCombinationView",
    "AdGroupAdAssetPolicySummary",
    "AdGroupAdAssetView",
    "AdGroupAdLabel",
    "AdGroupAdPolicySummary",
    "AdGroupAsset",
    "AdGroupAssetSet",
    "AdGroupAudienceView",
    "AdGroupBidModifier",
    "AdGroupCriterion",
    "AdGroupCriterionCustomizer",
    "AdGroupCriterionLabel",
    "AdGroupCriterionSimulation",
    "AdGroupCustomizer",
    "AdGroupExtensionSetting",
    "AdGroupFeed",
    "AdGroupLabel",
    "AdGroupSimulation",
    "AdParameter",
    "AdScheduleView",
    "AdvertisingPartnerIdentifier",
    "AdvertisingPartnerLinkInvitationIdentifier",
    "AgeRangeView",
    "AndroidPrivacySharedKeyGoogleAdGroup",
    "AndroidPrivacySharedKeyGoogleCampaign",
    "AndroidPrivacySharedKeyGoogleNetworkType",
    "Asset",
    "AssetFieldTypePolicySummary",
    "AssetFieldTypeView",
    "AssetGroup",
    "AssetGroupAsset",
    "AssetGroupAssetCombinationData",
    "AssetGroupListingGroupFilter",
    "AssetGroupProductGroupView",
    "AssetGroupSignal",
    "AssetGroupTopCombinationView",
    "AssetPolicySummary",
    "AssetSet",
    "AssetSetAsset",
    "AssetSetTypeView",
    "AttributeFieldMapping",
    "Audience",
    "BackgroundCheckVerificationArtifact",
    "BatchJob",
    "BiddingDataExclusion",
    "BiddingSeasonalityAdjustment",
    "BiddingStrategy",
    "BiddingStrategySimulation",
    "BillingSetup",
    "BusinessRegistrationCheckVerificationArtifact",
    "BusinessRegistrationDocument",
    "BusinessRegistrationNumber",
    "CallReportingSetting",
    "CallView",
    "Campaign",
    "CampaignAsset",
    "CampaignAssetSet",
    "CampaignAudienceView",
    "CampaignBidModifier",
    "CampaignBudget",
    "CampaignConversionGoal",
    "CampaignCriterion",
    "CampaignCustomizer",
    "CampaignDraft",
    "CampaignExtensionSetting",
    "CampaignFeed",
    "CampaignGroup",
    "CampaignLabel",
    "CampaignLifecycleGoal",
    "CampaignSearchTermInsight",
    "CampaignSharedSet",
    "CampaignSimulation",
    "CarrierConstant",
    "ChangeEvent",
    "ChangeStatus",
    "ClickView",
    "CombinedAudience",
    "ContactDetails",
    "ConversionAction",
    "ConversionCustomVariable",
    "ConversionGoalCampaignConfig",
    "ConversionTrackingSetting",
    "ConversionValueRule",
    "ConversionValueRuleSet",
    "CreditDetails",
    "CurrencyConstant",
    "CustomAudience",
    "CustomAudienceMember",
    "CustomConversionGoal",
    "CustomInterest",
    "CustomInterestMember",
    "CustomLeadFormSubmissionField",
    "Customer",
    "CustomerAcquisitionGoalSettings",
    "CustomerAgreementSetting",
    "CustomerAsset",
    "CustomerAssetSet",
    "CustomerClient",
    "CustomerClientLink",
    "CustomerConversionGoal",
    "CustomerCustomizer",
    "CustomerExtensionSetting",
    "CustomerFeed",
    "CustomerLabel",
    "CustomerLifecycleGoal",
    "CustomerManagerLink",
    "CustomerNegativeCriterion",
    "CustomerSearchTermInsight",
    "CustomerSkAdNetworkConversionValueSchema",
    "CustomerUserAccess",
    "CustomerUserAccessInvitation",
    "CustomizerAttribute",
    "DataPartnerIdentifier",
    "DetailPlacementView",
    "DetailedDemographic",
    "DisplayKeywordView",
    "DistanceView",
    "DomainCategory",
    "DynamicSearchAdsSearchTermView",
    "ExpandedLandingPageView",
    "Experiment",
    "ExperimentArm",
    "ExtensionFeedItem",
    "Feed",
    "FeedAttribute",
    "FeedAttributeOperation",
    "FeedItem",
    "FeedItemAttributeValue",
    "FeedItemPlaceholderPolicyInfo",
    "FeedItemSet",
    "FeedItemSetLink",
    "FeedItemTarget",
    "FeedItemValidationError",
    "FeedMapping",
    "FeedPlaceholderView",
    "Fellowship",
    "GenderView",
    "GeoTargetConstant",
    "GeographicView",
    "GoogleAdsField",
    "GoogleAdsIdentifier",
    "GranularInsuranceStatus",
    "GranularLicenseStatus",
    "GroupPlacementView",
    "HotelCenterLinkInvitationIdentifier",
    "HotelGroupView",
    "HotelPerformanceView",
    "HotelReconciliation",
    "IncomeRangeView",
    "InsuranceVerificationArtifact",
    "Invoice",
    "KeywordPlan",
    "KeywordPlanAdGroup",
    "KeywordPlanAdGroupKeyword",
    "KeywordPlanCampaign",
    "KeywordPlanCampaignKeyword",
    "KeywordPlanForecastPeriod",
    "KeywordPlanGeoTarget",
    "KeywordThemeConstant",
    "KeywordView",
    "Label",
    "LandingPageView",
    "LanguageConstant",
    "LeadFormSubmissionData",
    "LeadFormSubmissionField",
    "LicenseVerificationArtifact",
    "LifeEvent",
    "ListingGroupFilterDimension",
    "ListingGroupFilterDimensionPath",
    "LocalServicesEmployee",
    "LocalServicesLead",
    "LocalServicesLeadConversation",
    "LocalServicesSettings",
    "LocalServicesVerificationArtifact",
    "LocationView",
    "ManagedPlacementView",
    "MediaAudio",
    "MediaBundle",
    "MediaFile",
    "MediaImage",
    "MediaVideo",
    "MerchantCenterIdentifier",
    "MerchantCenterLinkInvitationIdentifier",
    "MessageDetails",
    "MobileAppCategoryConstant",
    "MobileDeviceConstant",
    "Note",
    "OfflineConversionAlert",
    "OfflineConversionError",
    "OfflineConversionSummary",
    "OfflineConversionUploadClientSummary",
    "OfflineUserDataJob",
    "OfflineUserDataJobMetadata",
    "OperatingSystemVersionConstant",
    "PaidOrganicSearchTermView",
    "ParentalStatusView",
    "PaymentsAccount",
    "PerStoreView",
    "PhoneCallDetails",
    "ProductCategoryConstant",
    "ProductGroupView",
    "ProductLink",
    "ProductLinkInvitation",
    "QualifyingQuestion",
    "Recommendation",
    "RecommendationSubscription",
    "RemarketingAction",
    "RemarketingSetting",
    "Residency",
    "SearchTermView",
    "SharedCriterion",
    "SharedSet",
    "ShoppingPerformanceView",
    "SmartCampaignSearchTermView",
    "SmartCampaignSetting",
    "ThirdPartyAppAnalyticsLink",
    "ThirdPartyAppAnalyticsLinkIdentifier",
    "TopicConstant",
    "TopicView",
    "TravelActivityGroupView",
    "TravelActivityPerformanceView",
    "UniversityDegree",
    "UserInterest",
    "UserList",
    "UserLocationView",
    "Video",
    "WebpageView",
]

# Names in __all__ with no definition:
#   AccessibleBiddingStrategy
#   AccountBudget
#   AccountBudgetProposal
#   AccountLink
#   Ad
#   AdGroup
#   AdGroupAd
#   AdGroupAdAssetCombinationView
#   AdGroupAdAssetPolicySummary
#   AdGroupAdAssetView
#   AdGroupAdLabel
#   AdGroupAdPolicySummary
#   AdGroupAsset
#   AdGroupAssetSet
#   AdGroupAudienceView
#   AdGroupBidModifier
#   AdGroupCriterion
#   AdGroupCriterionCustomizer
#   AdGroupCriterionLabel
#   AdGroupCriterionSimulation
#   AdGroupCustomizer
#   AdGroupExtensionSetting
#   AdGroupFeed
#   AdGroupLabel
#   AdGroupSimulation
#   AdParameter
#   AdScheduleView
#   AdvertisingPartnerIdentifier
#   AdvertisingPartnerLinkInvitationIdentifier
#   AgeRangeView
#   AndroidPrivacySharedKeyGoogleAdGroup
#   AndroidPrivacySharedKeyGoogleCampaign
#   AndroidPrivacySharedKeyGoogleNetworkType
#   Asset
#   AssetFieldTypePolicySummary
#   AssetFieldTypeView
#   AssetGroup
#   AssetGroupAsset
#   AssetGroupAssetCombinationData
#   AssetGroupListingGroupFilter
#   AssetGroupProductGroupView
#   AssetGroupSignal
#   AssetGroupTopCombinationView
#   AssetPolicySummary
#   AssetSet
#   AssetSetAsset
#   AssetSetTypeView
#   AttributeFieldMapping
#   Audience
#   BackgroundCheckVerificationArtifact
#   BatchJob
#   BiddingDataExclusion
#   BiddingSeasonalityAdjustment
#   BiddingStrategy
#   BiddingStrategySimulation
#   BillingSetup
#   BusinessRegistrationCheckVerificationArtifact
#   BusinessRegistrationDocument
#   BusinessRegistrationNumber
#   CallReportingSetting
#   CallView
#   Campaign
#   CampaignAsset
#   CampaignAssetSet
#   CampaignAudienceView
#   CampaignBidModifier
#   CampaignBudget
#   CampaignConversionGoal
#   CampaignCriterion
#   CampaignCustomizer
#   CampaignDraft
#   CampaignExtensionSetting
#   CampaignFeed
#   CampaignGroup
#   CampaignLabel
#   CampaignLifecycleGoal
#   CampaignSearchTermInsight
#   CampaignSharedSet
#   CampaignSimulation
#   CarrierConstant
#   ChangeEvent
#   ChangeStatus
#   ClickView
#   CombinedAudience
#   ContactDetails
#   ConversionAction
#   ConversionCustomVariable
#   ConversionGoalCampaignConfig
#   ConversionTrackingSetting
#   ConversionValueRule
#   ConversionValueRuleSet
#   CreditDetails
#   CurrencyConstant
#   CustomAudience
#   CustomAudienceMember
#   CustomConversionGoal
#   CustomInterest
#   CustomInterestMember
#   CustomLeadFormSubmissionField
#   Customer
#   CustomerAcquisitionGoalSettings
#   CustomerAgreementSetting
#   CustomerAsset
#   CustomerAssetSet
#   CustomerClient
#   CustomerClientLink
#   CustomerConversionGoal
#   CustomerCustomizer
#   CustomerExtensionSetting
#   CustomerFeed
#   CustomerLabel
#   CustomerLifecycleGoal
#   CustomerManagerLink
#   CustomerNegativeCriterion
#   CustomerSearchTermInsight
#   CustomerSkAdNetworkConversionValueSchema
#   CustomerUserAccess
#   CustomerUserAccessInvitation
#   CustomizerAttribute
#   DataPartnerIdentifier
#   DetailPlacementView
#   DetailedDemographic
#   DisplayKeywordView
#   DistanceView
#   DomainCategory
#   DynamicSearchAdsSearchTermView
#   ExpandedLandingPageView
#   Experiment
#   ExperimentArm
#   ExtensionFeedItem
#   Feed
#   FeedAttribute
#   FeedAttributeOperation
#   FeedItem
#   FeedItemAttributeValue
#   FeedItemPlaceholderPolicyInfo
#   FeedItemSet
#   FeedItemSetLink
#   FeedItemTarget
#   FeedItemValidationError
#   FeedMapping
#   FeedPlaceholderView
#   Fellowship
#   GenderView
#   GeoTargetConstant
#   GeographicView
#   GoogleAdsField
#   GoogleAdsIdentifier
#   GranularInsuranceStatus
#   GranularLicenseStatus
#   GroupPlacementView
#   HotelCenterLinkInvitationIdentifier
#   HotelGroupView
#   HotelPerformanceView
#   HotelReconciliation
#   IncomeRangeView
#   InsuranceVerificationArtifact
#   Invoice
#   KeywordPlan
#   KeywordPlanAdGroup
#   KeywordPlanAdGroupKeyword
#   KeywordPlanCampaign
#   KeywordPlanCampaignKeyword
#   KeywordPlanForecastPeriod
#   KeywordPlanGeoTarget
#   KeywordThemeConstant
#   KeywordView
#   Label
#   LandingPageView
#   LanguageConstant
#   LeadFormSubmissionData
#   LeadFormSubmissionField
#   LicenseVerificationArtifact
#   LifeEvent
#   ListingGroupFilterDimension
#   ListingGroupFilterDimensionPath
#   LocalServicesEmployee
#   LocalServicesLead
#   LocalServicesLeadConversation
#   LocalServicesSettings
#   LocalServicesVerificationArtifact
#   LocationView
#   ManagedPlacementView
#   MediaAudio
#   MediaBundle
#   MediaFile
#   MediaImage
#   MediaVideo
#   MerchantCenterIdentifier
#   MerchantCenterLinkInvitationIdentifier
#   MessageDetails
#   MobileAppCategoryConstant
#   MobileDeviceConstant
#   Note
#   OfflineConversionAlert
#   OfflineConversionError
#   OfflineConversionSummary
#   OfflineConversionUploadClientSummary
#   OfflineUserDataJob
#   OfflineUserDataJobMetadata
#   OperatingSystemVersionConstant
#   PaidOrganicSearchTermView
#   ParentalStatusView
#   PaymentsAccount
#   PerStoreView
#   PhoneCallDetails
#   ProductCategoryConstant
#   ProductGroupView
#   ProductLink
#   ProductLinkInvitation
#   QualifyingQuestion
#   Recommendation
#   RecommendationSubscription
#   RemarketingAction
#   RemarketingSetting
#   Residency
#   SearchTermView
#   SharedCriterion
#   SharedSet
#   ShoppingPerformanceView
#   SmartCampaignSearchTermView
#   SmartCampaignSetting
#   ThirdPartyAppAnalyticsLink
#   ThirdPartyAppAnalyticsLinkIdentifier
#   TopicConstant
#   TopicView
#   TravelActivityGroupView
#   TravelActivityPerformanceView
#   UniversityDegree
#   UserInterest
#   UserList
#   UserLocationView
#   Video
#   WebpageView



from .base import AdGroupAdLabelServiceTransport as AdGroupAdLabelServiceTransport
from .grpc import (
    AdGroupAdLabelServiceGrpcTransport as AdGroupAdLabelServiceGrpcTransport,
)

__all__ = ["AdGroupAdLabelServiceTransport", "AdGroupAdLabelServiceGrpcTransport"]



from .base import SharedCriterionServiceTransport as SharedCriterionServiceTransport
from .grpc import (
    SharedCriterionServiceGrpcTransport as SharedCriterionServiceGrpcTransport,
)

__all__ = ["SharedCriterionServiceTransport", "SharedCriterionServiceGrpcTransport"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v16.common.types.consent import Consent
from google.ads.googleads.v16.common.types.offline_user_data import UserIdentifier
from google.ads.googleads.v16.enums.types.conversion_environment_enum import (
    ConversionEnvironmentEnum,
)

_M = TypeVar("_M")

class CallConversion(proto.Message):
    caller_id: str
    call_start_date_time: str
    conversion_action: str
    conversion_date_time: str
    conversion_value: float
    currency_code: str
    custom_variables: MutableSequence[CustomVariable]
    consent: Consent
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        caller_id: str = ...,
        call_start_date_time: str = ...,
        conversion_action: str = ...,
        conversion_date_time: str = ...,
        conversion_value: float = ...,
        currency_code: str = ...,
        custom_variables: MutableSequence[CustomVariable] = ...,
        consent: Consent = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "caller_id",
            "call_start_date_time",
            "conversion_action",
            "conversion_date_time",
            "conversion_value",
            "currency_code",
            "custom_variables",
            "consent",
        ],
    ) -> bool: ...

class CallConversionResult(proto.Message):
    caller_id: str
    call_start_date_time: str
    conversion_action: str
    conversion_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        caller_id: str = ...,
        call_start_date_time: str = ...,
        conversion_action: str = ...,
        conversion_date_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "caller_id",
            "call_start_date_time",
            "conversion_action",
            "conversion_date_time",
        ],
    ) -> bool: ...

class CartData(proto.Message):
    class Item(proto.Message):
        product_id: str
        quantity: int
        unit_price: float
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            product_id: str = ...,
            quantity: int = ...,
            unit_price: float = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["product_id", "quantity", "unit_price"]
        ) -> bool: ...

    merchant_id: int
    feed_country_code: str
    feed_language_code: str
    local_transaction_cost: float
    items: MutableSequence[CartData.Item]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        merchant_id: int = ...,
        feed_country_code: str = ...,
        feed_language_code: str = ...,
        local_transaction_cost: float = ...,
        items: MutableSequence[CartData.Item] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "merchant_id",
            "feed_country_code",
            "feed_language_code",
            "local_transaction_cost",
            "items",
        ],
    ) -> bool: ...

class ClickConversion(proto.Message):
    gclid: str
    gbraid: str
    wbraid: str
    conversion_action: str
    conversion_date_time: str
    conversion_value: float
    currency_code: str
    order_id: str
    external_attribution_data: ExternalAttributionData
    custom_variables: MutableSequence[CustomVariable]
    cart_data: CartData
    user_identifiers: MutableSequence[UserIdentifier]
    conversion_environment: ConversionEnvironmentEnum.ConversionEnvironment
    consent: Consent
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        gclid: str = ...,
        gbraid: str = ...,
        wbraid: str = ...,
        conversion_action: str = ...,
        conversion_date_time: str = ...,
        conversion_value: float = ...,
        currency_code: str = ...,
        order_id: str = ...,
        external_attribution_data: ExternalAttributionData = ...,
        custom_variables: MutableSequence[CustomVariable] = ...,
        cart_data: CartData = ...,
        user_identifiers: MutableSequence[UserIdentifier] = ...,
        conversion_environment: ConversionEnvironmentEnum.ConversionEnvironment = ...,
        consent: Consent = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "gclid",
            "gbraid",
            "wbraid",
            "conversion_action",
            "conversion_date_time",
            "conversion_value",
            "currency_code",
            "order_id",
            "external_attribution_data",
            "custom_variables",
            "cart_data",
            "user_identifiers",
            "conversion_environment",
            "consent",
        ],
    ) -> bool: ...

class ClickConversionResult(proto.Message):
    gclid: str
    gbraid: str
    wbraid: str
    conversion_action: str
    conversion_date_time: str
    user_identifiers: MutableSequence[UserIdentifier]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        gclid: str = ...,
        gbraid: str = ...,
        wbraid: str = ...,
        conversion_action: str = ...,
        conversion_date_time: str = ...,
        user_identifiers: MutableSequence[UserIdentifier] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "gclid",
            "gbraid",
            "wbraid",
            "conversion_action",
            "conversion_date_time",
            "user_identifiers",
        ],
    ) -> bool: ...

class CustomVariable(proto.Message):
    conversion_custom_variable: str
    value: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        conversion_custom_variable: str = ...,
        value: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["conversion_custom_variable", "value"]
    ) -> bool: ...

class ExternalAttributionData(proto.Message):
    external_attribution_credit: float
    external_attribution_model: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        external_attribution_credit: float = ...,
        external_attribution_model: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["external_attribution_credit", "external_attribution_model"]
    ) -> bool: ...

class UploadCallConversionsRequest(proto.Message):
    customer_id: str
    conversions: MutableSequence[CallConversion]
    partial_failure: bool
    validate_only: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        conversions: MutableSequence[CallConversion] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["customer_id", "conversions", "partial_failure", "validate_only"],
    ) -> bool: ...

class UploadCallConversionsResponse(proto.Message):
    partial_failure_error: Status
    results: MutableSequence[CallConversionResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        partial_failure_error: Status = ...,
        results: MutableSequence[CallConversionResult] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["partial_failure_error", "results"]
    ) -> bool: ...

class UploadClickConversionsRequest(proto.Message):
    customer_id: str
    conversions: MutableSequence[ClickConversion]
    partial_failure: bool
    validate_only: bool
    debug_enabled: bool
    job_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        conversions: MutableSequence[ClickConversion] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        debug_enabled: bool = ...,
        job_id: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "conversions",
            "partial_failure",
            "validate_only",
            "debug_enabled",
            "job_id",
        ],
    ) -> bool: ...

class UploadClickConversionsResponse(proto.Message):
    partial_failure_error: Status
    results: MutableSequence[ClickConversionResult]
    job_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        partial_failure_error: Status = ...,
        results: MutableSequence[ClickConversionResult] = ...,
        job_id: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["partial_failure_error", "results", "job_id"]
    ) -> bool: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v17.common.types.lifecycle_goals import (
    LifecycleGoalValueSettings,
)
from google.ads.googleads.v17.enums.types.customer_acquisition_optimization_mode import (
    CustomerAcquisitionOptimizationModeEnum,
)

_M = TypeVar("_M")

class CampaignLifecycleGoal(proto.Message):
    resource_name: str
    campaign: str
    customer_acquisition_goal_settings: CustomerAcquisitionGoalSettings
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        campaign: str = ...,
        customer_acquisition_goal_settings: CustomerAcquisitionGoalSettings = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["resource_name", "campaign", "customer_acquisition_goal_settings"],
    ) -> bool: ...

class CustomerAcquisitionGoalSettings(proto.Message):
    optimization_mode: (
        CustomerAcquisitionOptimizationModeEnum.CustomerAcquisitionOptimizationMode
    )
    value_settings: LifecycleGoalValueSettings
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        optimization_mode: CustomerAcquisitionOptimizationModeEnum.CustomerAcquisitionOptimizationMode = ...,
        value_settings: LifecycleGoalValueSettings = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["optimization_mode", "value_settings"]
    ) -> bool: ...



from .base import (
    CampaignConversionGoalServiceTransport as CampaignConversionGoalServiceTransport,
)
from .grpc import (
    CampaignConversionGoalServiceGrpcTransport as CampaignConversionGoalServiceGrpcTransport,
)

__all__ = [
    "CampaignConversionGoalServiceTransport",
    "CampaignConversionGoalServiceGrpcTransport",
]



from .base import UserListServiceTransport as UserListServiceTransport
from .grpc import UserListServiceGrpcTransport as UserListServiceGrpcTransport

__all__ = ["UserListServiceTransport", "UserListServiceGrpcTransport"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v16.common.types.criteria import AudienceInfo, SearchThemeInfo
from google.ads.googleads.v16.enums.types.asset_group_signal_approval_status import (
    AssetGroupSignalApprovalStatusEnum,
)

_M = TypeVar("_M")

class AssetGroupSignal(proto.Message):
    resource_name: str
    asset_group: str
    approval_status: AssetGroupSignalApprovalStatusEnum.AssetGroupSignalApprovalStatus
    disapproval_reasons: MutableSequence[str]
    audience: AudienceInfo
    search_theme: SearchThemeInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        asset_group: str = ...,
        approval_status: AssetGroupSignalApprovalStatusEnum.AssetGroupSignalApprovalStatus = ...,
        disapproval_reasons: MutableSequence[str] = ...,
        audience: AudienceInfo = ...,
        search_theme: SearchThemeInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "asset_group",
            "approval_status",
            "disapproval_reasons",
            "audience",
            "search_theme",
        ],
    ) -> bool: ...



from .base import CustomerFeedServiceTransport as CustomerFeedServiceTransport
from .grpc import CustomerFeedServiceGrpcTransport as CustomerFeedServiceGrpcTransport

__all__ = ["CustomerFeedServiceTransport", "CustomerFeedServiceGrpcTransport"]



from .base import FeedItemServiceTransport as FeedItemServiceTransport
from .grpc import FeedItemServiceGrpcTransport as FeedItemServiceGrpcTransport

__all__ = ["FeedItemServiceTransport", "FeedItemServiceGrpcTransport"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class AssetGroupListingGroupFilterErrorEnum(proto.Message):
    class AssetGroupListingGroupFilterError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        TREE_TOO_DEEP = 2
        UNIT_CANNOT_HAVE_CHILDREN = 3
        SUBDIVISION_MUST_HAVE_EVERYTHING_ELSE_CHILD = 4
        DIFFERENT_DIMENSION_TYPE_BETWEEN_SIBLINGS = 5
        SAME_DIMENSION_VALUE_BETWEEN_SIBLINGS = 6
        SAME_DIMENSION_TYPE_BETWEEN_ANCESTORS = 7
        MULTIPLE_ROOTS = 8
        INVALID_DIMENSION_VALUE = 9
        MUST_REFINE_HIERARCHICAL_PARENT_TYPE = 10
        INVALID_PRODUCT_BIDDING_CATEGORY = 11
        CHANGING_CASE_VALUE_WITH_CHILDREN = 12
        SUBDIVISION_HAS_CHILDREN = 13
        CANNOT_REFINE_HIERARCHICAL_EVERYTHING_ELSE = 14
        DIMENSION_TYPE_NOT_ALLOWED = 15
        DUPLICATE_WEBPAGE_FILTER_UNDER_ASSET_GROUP = 16
        LISTING_SOURCE_NOT_ALLOWED = 17
        FILTER_EXCLUSION_NOT_ALLOWED = 18
        MULTIPLE_LISTING_SOURCES = 19
        MULTIPLE_WEBPAGE_CONDITION_TYPES_NOT_ALLOWED = 20
        MULTIPLE_WEBPAGE_TYPES_PER_ASSET_GROUP = 21
        PAGE_FEED_FILTER_HAS_PARENT = 22
        MULTIPLE_OPERATIONS_ON_ONE_NODE = 23

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...



from .base import (
    CustomerConversionGoalServiceTransport as CustomerConversionGoalServiceTransport,
)
from .grpc import (
    CustomerConversionGoalServiceGrpcTransport as CustomerConversionGoalServiceGrpcTransport,
)

__all__ = [
    "CustomerConversionGoalServiceTransport",
    "CustomerConversionGoalServiceGrpcTransport",
]



from .base import FeedItemSetLinkServiceTransport as FeedItemSetLinkServiceTransport
from .grpc import (
    FeedItemSetLinkServiceGrpcTransport as FeedItemSetLinkServiceGrpcTransport,
)

__all__ = ["FeedItemSetLinkServiceTransport", "FeedItemSetLinkServiceGrpcTransport"]



from .base import AdGroupAssetServiceTransport as AdGroupAssetServiceTransport
from .grpc import AdGroupAssetServiceGrpcTransport as AdGroupAssetServiceGrpcTransport

__all__ = ["AdGroupAssetServiceTransport", "AdGroupAssetServiceGrpcTransport"]



from .base import KeywordPlanIdeaServiceTransport as KeywordPlanIdeaServiceTransport
from .grpc import (
    KeywordPlanIdeaServiceGrpcTransport as KeywordPlanIdeaServiceGrpcTransport,
)

__all__ = ["KeywordPlanIdeaServiceTransport", "KeywordPlanIdeaServiceGrpcTransport"]



__all__ = [
    "AccessInvitationErrorEnum",
    "AccountBudgetProposalErrorEnum",
    "AccountLinkErrorEnum",
    "AdCustomizerErrorEnum",
    "AdErrorEnum",
    "AdGroupAdErrorEnum",
    "AdGroupBidModifierErrorEnum",
    "AdGroupCriterionCustomizerErrorEnum",
    "AdGroupCriterionErrorEnum",
    "AdGroupCustomizerErrorEnum",
    "AdGroupErrorEnum",
    "AdGroupFeedErrorEnum",
    "AdParameterErrorEnum",
    "AdSharingErrorEnum",
    "AdxErrorEnum",
    "AssetErrorEnum",
    "AssetGroupAssetErrorEnum",
    "AssetGroupErrorEnum",
    "AssetGroupListingGroupFilterErrorEnum",
    "AssetGroupSignalErrorEnum",
    "AssetLinkErrorEnum",
    "AssetSetAssetErrorEnum",
    "AssetSetErrorEnum",
    "AssetSetLinkErrorEnum",
    "AudienceErrorEnum",
    "AudienceInsightsErrorEnum",
    "AuthenticationErrorEnum",
    "AuthorizationErrorEnum",
    "BatchJobErrorEnum",
    "BiddingErrorEnum",
    "BiddingStrategyErrorEnum",
    "BillingSetupErrorEnum",
    "CampaignBudgetErrorEnum",
    "CampaignConversionGoalErrorEnum",
    "CampaignCriterionErrorEnum",
    "CampaignCustomizerErrorEnum",
    "CampaignDraftErrorEnum",
    "CampaignErrorEnum",
    "CampaignExperimentErrorEnum",
    "CampaignFeedErrorEnum",
    "CampaignLifecycleGoalErrorEnum",
    "CampaignSharedSetErrorEnum",
    "ChangeEventErrorEnum",
    "ChangeStatusErrorEnum",
    "CollectionSizeErrorEnum",
    "ContextErrorEnum",
    "ConversionActionErrorEnum",
    "ConversionAdjustmentUploadErrorEnum",
    "ConversionCustomVariableErrorEnum",
    "ConversionGoalCampaignConfigErrorEnum",
    "ConversionUploadErrorEnum",
    "ConversionValueRuleErrorEnum",
    "ConversionValueRuleSetErrorEnum",
    "CountryCodeErrorEnum",
    "CriterionErrorEnum",
    "CurrencyCodeErrorEnum",
    "CurrencyErrorEnum",
    "CustomAudienceErrorEnum",
    "CustomConversionGoalErrorEnum",
    "CustomInterestErrorEnum",
    "CustomerClientLinkErrorEnum",
    "CustomerCustomizerErrorEnum",
    "CustomerErrorEnum",
    "CustomerFeedErrorEnum",
    "CustomerLifecycleGoalErrorEnum",
    "CustomerManagerLinkErrorEnum",
    "CustomerSkAdNetworkConversionValueSchemaErrorEnum",
    "CustomerUserAccessErrorEnum",
    "CustomizerAttributeErrorEnum",
    "DatabaseErrorEnum",
    "DateErrorEnum",
    "DateRangeErrorEnum",
    "DistinctErrorEnum",
    "EnumErrorEnum",
    "ErrorCode",
    "ErrorDetails",
    "ErrorLocation",
    "ExperimentArmErrorEnum",
    "ExperimentErrorEnum",
    "ExtensionFeedItemErrorEnum",
    "ExtensionSettingErrorEnum",
    "FeedAttributeReferenceErrorEnum",
    "FeedErrorEnum",
    "FeedItemErrorEnum",
    "FeedItemSetErrorEnum",
    "FeedItemSetLinkErrorEnum",
    "FeedItemTargetErrorEnum",
    "FeedItemValidationErrorEnum",
    "FeedMappingErrorEnum",
    "FieldErrorEnum",
    "FieldMaskErrorEnum",
    "FunctionErrorEnum",
    "FunctionParsingErrorEnum",
    "GeoTargetConstantSuggestionErrorEnum",
    "GoogleAdsError",
    "GoogleAdsFailure",
    "HeaderErrorEnum",
    "IdErrorEnum",
    "IdentityVerificationErrorEnum",
    "ImageErrorEnum",
    "InternalErrorEnum",
    "InvoiceErrorEnum",
    "KeywordPlanAdGroupErrorEnum",
    "KeywordPlanAdGroupKeywordErrorEnum",
    "KeywordPlanCampaignErrorEnum",
    "KeywordPlanCampaignKeywordErrorEnum",
    "KeywordPlanErrorEnum",
    "KeywordPlanIdeaErrorEnum",
    "LabelErrorEnum",
    "LanguageCodeErrorEnum",
    "ListOperationErrorEnum",
    "ManagerLinkErrorEnum",
    "MediaBundleErrorEnum",
    "MediaFileErrorEnum",
    "MediaUploadErrorEnum",
    "MerchantCenterErrorEnum",
    "MultiplierErrorEnum",
    "MutateErrorEnum",
    "NewResourceCreationErrorEnum",
    "NotAllowlistedErrorEnum",
    "NotEmptyErrorEnum",
    "NullErrorEnum",
    "OfflineUserDataJobErrorEnum",
    "OperationAccessDeniedErrorEnum",
    "OperatorErrorEnum",
    "PartialFailureErrorEnum",
    "PaymentsAccountErrorEnum",
    "PolicyFindingDetails",
    "PolicyFindingErrorEnum",
    "PolicyValidationParameterErrorEnum",
    "PolicyViolationDetails",
    "PolicyViolationErrorEnum",
    "ProductLinkErrorEnum",
    "ProductLinkInvitationErrorEnum",
    "QueryErrorEnum",
    "QuotaErrorDetails",
    "QuotaErrorEnum",
    "RangeErrorEnum",
    "ReachPlanErrorEnum",
    "RecommendationErrorEnum",
    "RecommendationSubscriptionErrorEnum",
    "RegionCodeErrorEnum",
    "RequestErrorEnum",
    "ResourceAccessDeniedErrorEnum",
    "ResourceCountDetails",
    "ResourceCountLimitExceededErrorEnum",
    "SearchTermInsightErrorEnum",
    "SettingErrorEnum",
    "SharedCriterionErrorEnum",
    "SharedSetErrorEnum",
    "SizeLimitErrorEnum",
    "SmartCampaignErrorEnum",
    "StringFormatErrorEnum",
    "StringLengthErrorEnum",
    "ThirdPartyAppAnalyticsLinkErrorEnum",
    "TimeZoneErrorEnum",
    "UrlFieldErrorEnum",
    "UserDataErrorEnum",
    "UserListErrorEnum",
    "VideoCampaignErrorEnum",
    "YoutubeVideoRegistrationErrorEnum",
]

# Names in __all__ with no definition:
#   AccessInvitationErrorEnum
#   AccountBudgetProposalErrorEnum
#   AccountLinkErrorEnum
#   AdCustomizerErrorEnum
#   AdErrorEnum
#   AdGroupAdErrorEnum
#   AdGroupBidModifierErrorEnum
#   AdGroupCriterionCustomizerErrorEnum
#   AdGroupCriterionErrorEnum
#   AdGroupCustomizerErrorEnum
#   AdGroupErrorEnum
#   AdGroupFeedErrorEnum
#   AdParameterErrorEnum
#   AdSharingErrorEnum
#   AdxErrorEnum
#   AssetErrorEnum
#   AssetGroupAssetErrorEnum
#   AssetGroupErrorEnum
#   AssetGroupListingGroupFilterErrorEnum
#   AssetGroupSignalErrorEnum
#   AssetLinkErrorEnum
#   AssetSetAssetErrorEnum
#   AssetSetErrorEnum
#   AssetSetLinkErrorEnum
#   AudienceErrorEnum
#   AudienceInsightsErrorEnum
#   AuthenticationErrorEnum
#   AuthorizationErrorEnum
#   BatchJobErrorEnum
#   BiddingErrorEnum
#   BiddingStrategyErrorEnum
#   BillingSetupErrorEnum
#   CampaignBudgetErrorEnum
#   CampaignConversionGoalErrorEnum
#   CampaignCriterionErrorEnum
#   CampaignCustomizerErrorEnum
#   CampaignDraftErrorEnum
#   CampaignErrorEnum
#   CampaignExperimentErrorEnum
#   CampaignFeedErrorEnum
#   CampaignLifecycleGoalErrorEnum
#   CampaignSharedSetErrorEnum
#   ChangeEventErrorEnum
#   ChangeStatusErrorEnum
#   CollectionSizeErrorEnum
#   ContextErrorEnum
#   ConversionActionErrorEnum
#   ConversionAdjustmentUploadErrorEnum
#   ConversionCustomVariableErrorEnum
#   ConversionGoalCampaignConfigErrorEnum
#   ConversionUploadErrorEnum
#   ConversionValueRuleErrorEnum
#   ConversionValueRuleSetErrorEnum
#   CountryCodeErrorEnum
#   CriterionErrorEnum
#   CurrencyCodeErrorEnum
#   CurrencyErrorEnum
#   CustomAudienceErrorEnum
#   CustomConversionGoalErrorEnum
#   CustomInterestErrorEnum
#   CustomerClientLinkErrorEnum
#   CustomerCustomizerErrorEnum
#   CustomerErrorEnum
#   CustomerFeedErrorEnum
#   CustomerLifecycleGoalErrorEnum
#   CustomerManagerLinkErrorEnum
#   CustomerSkAdNetworkConversionValueSchemaErrorEnum
#   CustomerUserAccessErrorEnum
#   CustomizerAttributeErrorEnum
#   DatabaseErrorEnum
#   DateErrorEnum
#   DateRangeErrorEnum
#   DistinctErrorEnum
#   EnumErrorEnum
#   ErrorCode
#   ErrorDetails
#   ErrorLocation
#   ExperimentArmErrorEnum
#   ExperimentErrorEnum
#   ExtensionFeedItemErrorEnum
#   ExtensionSettingErrorEnum
#   FeedAttributeReferenceErrorEnum
#   FeedErrorEnum
#   FeedItemErrorEnum
#   FeedItemSetErrorEnum
#   FeedItemSetLinkErrorEnum
#   FeedItemTargetErrorEnum
#   FeedItemValidationErrorEnum
#   FeedMappingErrorEnum
#   FieldErrorEnum
#   FieldMaskErrorEnum
#   FunctionErrorEnum
#   FunctionParsingErrorEnum
#   GeoTargetConstantSuggestionErrorEnum
#   GoogleAdsError
#   GoogleAdsFailure
#   HeaderErrorEnum
#   IdErrorEnum
#   IdentityVerificationErrorEnum
#   ImageErrorEnum
#   InternalErrorEnum
#   InvoiceErrorEnum
#   KeywordPlanAdGroupErrorEnum
#   KeywordPlanAdGroupKeywordErrorEnum
#   KeywordPlanCampaignErrorEnum
#   KeywordPlanCampaignKeywordErrorEnum
#   KeywordPlanErrorEnum
#   KeywordPlanIdeaErrorEnum
#   LabelErrorEnum
#   LanguageCodeErrorEnum
#   ListOperationErrorEnum
#   ManagerLinkErrorEnum
#   MediaBundleErrorEnum
#   MediaFileErrorEnum
#   MediaUploadErrorEnum
#   MerchantCenterErrorEnum
#   MultiplierErrorEnum
#   MutateErrorEnum
#   NewResourceCreationErrorEnum
#   NotAllowlistedErrorEnum
#   NotEmptyErrorEnum
#   NullErrorEnum
#   OfflineUserDataJobErrorEnum
#   OperationAccessDeniedErrorEnum
#   OperatorErrorEnum
#   PartialFailureErrorEnum
#   PaymentsAccountErrorEnum
#   PolicyFindingDetails
#   PolicyFindingErrorEnum
#   PolicyValidationParameterErrorEnum
#   PolicyViolationDetails
#   PolicyViolationErrorEnum
#   ProductLinkErrorEnum
#   ProductLinkInvitationErrorEnum
#   QueryErrorEnum
#   QuotaErrorDetails
#   QuotaErrorEnum
#   RangeErrorEnum
#   ReachPlanErrorEnum
#   RecommendationErrorEnum
#   RecommendationSubscriptionErrorEnum
#   RegionCodeErrorEnum
#   RequestErrorEnum
#   ResourceAccessDeniedErrorEnum
#   ResourceCountDetails
#   ResourceCountLimitExceededErrorEnum
#   SearchTermInsightErrorEnum
#   SettingErrorEnum
#   SharedCriterionErrorEnum
#   SharedSetErrorEnum
#   SizeLimitErrorEnum
#   SmartCampaignErrorEnum
#   StringFormatErrorEnum
#   StringLengthErrorEnum
#   ThirdPartyAppAnalyticsLinkErrorEnum
#   TimeZoneErrorEnum
#   UrlFieldErrorEnum
#   UserDataErrorEnum
#   UserListErrorEnum
#   VideoCampaignErrorEnum
#   YoutubeVideoRegistrationErrorEnum



from .base import AudienceInsightsServiceTransport as AudienceInsightsServiceTransport
from .grpc import (
    AudienceInsightsServiceGrpcTransport as AudienceInsightsServiceGrpcTransport,
)

__all__ = ["AudienceInsightsServiceTransport", "AudienceInsightsServiceGrpcTransport"]



from .base import (
    IdentityVerificationServiceTransport as IdentityVerificationServiceTransport,
)
from .grpc import (
    IdentityVerificationServiceGrpcTransport as IdentityVerificationServiceGrpcTransport,
)

__all__ = [
    "IdentityVerificationServiceTransport",
    "IdentityVerificationServiceGrpcTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v16.enums.types.local_services_lead_credit_state import (
    LocalServicesCreditStateEnum,
)
from google.ads.googleads.v16.enums.types.local_services_lead_status import (
    LocalServicesLeadStatusEnum,
)
from google.ads.googleads.v16.enums.types.local_services_lead_type import (
    LocalServicesLeadTypeEnum,
)

_M = TypeVar("_M")

class ContactDetails(proto.Message):
    phone_number: str
    email: str
    consumer_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        phone_number: str = ...,
        email: str = ...,
        consumer_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["phone_number", "email", "consumer_name"]
    ) -> bool: ...

class CreditDetails(proto.Message):
    credit_state: LocalServicesCreditStateEnum.CreditState
    credit_state_last_update_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        credit_state: LocalServicesCreditStateEnum.CreditState = ...,
        credit_state_last_update_date_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["credit_state", "credit_state_last_update_date_time"]
    ) -> bool: ...

class LocalServicesLead(proto.Message):
    resource_name: str
    id: int
    category_id: str
    service_id: str
    contact_details: ContactDetails
    lead_type: LocalServicesLeadTypeEnum.LeadType
    lead_status: LocalServicesLeadStatusEnum.LeadStatus
    creation_date_time: str
    locale: str
    note: Note
    lead_charged: bool
    credit_details: CreditDetails
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        category_id: str = ...,
        service_id: str = ...,
        contact_details: ContactDetails = ...,
        lead_type: LocalServicesLeadTypeEnum.LeadType = ...,
        lead_status: LocalServicesLeadStatusEnum.LeadStatus = ...,
        creation_date_time: str = ...,
        locale: str = ...,
        note: Note = ...,
        lead_charged: bool = ...,
        credit_details: CreditDetails = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "id",
            "category_id",
            "service_id",
            "contact_details",
            "lead_type",
            "lead_status",
            "creation_date_time",
            "locale",
            "note",
            "lead_charged",
            "credit_details",
        ],
    ) -> bool: ...

class Note(proto.Message):
    edit_date_time: str
    description: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        edit_date_time: str = ...,
        description: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["edit_date_time", "description"]
    ) -> bool: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v16.enums.types.access_invitation_status import (
    AccessInvitationStatusEnum,
)
from google.ads.googleads.v16.enums.types.access_role import AccessRoleEnum

_M = TypeVar("_M")

class CustomerUserAccessInvitation(proto.Message):
    resource_name: str
    invitation_id: int
    access_role: AccessRoleEnum.AccessRole
    email_address: str
    creation_date_time: str
    invitation_status: AccessInvitationStatusEnum.AccessInvitationStatus
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        invitation_id: int = ...,
        access_role: AccessRoleEnum.AccessRole = ...,
        email_address: str = ...,
        creation_date_time: str = ...,
        invitation_status: AccessInvitationStatusEnum.AccessInvitationStatus = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "invitation_id",
            "access_role",
            "email_address",
            "creation_date_time",
            "invitation_status",
        ],
    ) -> bool: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v16.enums.types.local_services_employee_status import (
    LocalServicesEmployeeStatusEnum,
)
from google.ads.googleads.v16.enums.types.local_services_employee_type import (
    LocalServicesEmployeeTypeEnum,
)

_M = TypeVar("_M")

class Fellowship(proto.Message):
    institution_name: str
    completion_year: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        institution_name: str = ...,
        completion_year: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["institution_name", "completion_year"]
    ) -> bool: ...

class LocalServicesEmployee(proto.Message):
    resource_name: str
    id: int
    creation_date_time: str
    status: LocalServicesEmployeeStatusEnum.LocalServicesEmployeeStatus
    type_: LocalServicesEmployeeTypeEnum.LocalServicesEmployeeType
    university_degrees: MutableSequence[UniversityDegree]
    residencies: MutableSequence[Residency]
    fellowships: MutableSequence[Fellowship]
    job_title: str
    year_started_practicing: int
    languages_spoken: MutableSequence[str]
    category_ids: MutableSequence[str]
    national_provider_id_number: str
    email_address: str
    first_name: str
    middle_name: str
    last_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        creation_date_time: str = ...,
        status: LocalServicesEmployeeStatusEnum.LocalServicesEmployeeStatus = ...,
        type_: LocalServicesEmployeeTypeEnum.LocalServicesEmployeeType = ...,
        university_degrees: MutableSequence[UniversityDegree] = ...,
        residencies: MutableSequence[Residency] = ...,
        fellowships: MutableSequence[Fellowship] = ...,
        job_title: str = ...,
        year_started_practicing: int = ...,
        languages_spoken: MutableSequence[str] = ...,
        category_ids: MutableSequence[str] = ...,
        national_provider_id_number: str = ...,
        email_address: str = ...,
        first_name: str = ...,
        middle_name: str = ...,
        last_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "id",
            "creation_date_time",
            "status",
            "type_",
            "university_degrees",
            "residencies",
            "fellowships",
            "job_title",
            "year_started_practicing",
            "languages_spoken",
            "category_ids",
            "national_provider_id_number",
            "email_address",
            "first_name",
            "middle_name",
            "last_name",
        ],
    ) -> bool: ...

class Residency(proto.Message):
    institution_name: str
    completion_year: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        institution_name: str = ...,
        completion_year: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["institution_name", "completion_year"]
    ) -> bool: ...

class UniversityDegree(proto.Message):
    institution_name: str
    degree: str
    graduation_year: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        institution_name: str = ...,
        degree: str = ...,
        graduation_year: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["institution_name", "degree", "graduation_year"]
    ) -> bool: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v17.enums.types.local_services_conversation_type import (
    LocalServicesLeadConversationTypeEnum,
)
from google.ads.googleads.v17.enums.types.local_services_participant_type import (
    LocalServicesParticipantTypeEnum,
)

_M = TypeVar("_M")

class LocalServicesLeadConversation(proto.Message):
    resource_name: str
    id: int
    conversation_channel: LocalServicesLeadConversationTypeEnum.ConversationType
    participant_type: LocalServicesParticipantTypeEnum.ParticipantType
    lead: str
    event_date_time: str
    phone_call_details: PhoneCallDetails
    message_details: MessageDetails
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        conversation_channel: LocalServicesLeadConversationTypeEnum.ConversationType = ...,
        participant_type: LocalServicesParticipantTypeEnum.ParticipantType = ...,
        lead: str = ...,
        event_date_time: str = ...,
        phone_call_details: PhoneCallDetails = ...,
        message_details: MessageDetails = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "id",
            "conversation_channel",
            "participant_type",
            "lead",
            "event_date_time",
            "phone_call_details",
            "message_details",
        ],
    ) -> bool: ...

class MessageDetails(proto.Message):
    text: str
    attachment_urls: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        text: str = ...,
        attachment_urls: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["text", "attachment_urls"]
    ) -> bool: ...

class PhoneCallDetails(proto.Message):
    call_duration_millis: int
    call_recording_url: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        call_duration_millis: int = ...,
        call_recording_url: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["call_duration_millis", "call_recording_url"]
    ) -> bool: ...



from .base import FeedItemTargetServiceTransport as FeedItemTargetServiceTransport
from .grpc import (
    FeedItemTargetServiceGrpcTransport as FeedItemTargetServiceGrpcTransport,
)

__all__ = ["FeedItemTargetServiceTransport", "FeedItemTargetServiceGrpcTransport"]



from .base import AdGroupServiceTransport as AdGroupServiceTransport
from .grpc import AdGroupServiceGrpcTransport as AdGroupServiceGrpcTransport

__all__ = ["AdGroupServiceTransport", "AdGroupServiceGrpcTransport"]



from .base import BrandSuggestionServiceTransport as BrandSuggestionServiceTransport
from .grpc import (
    BrandSuggestionServiceGrpcTransport as BrandSuggestionServiceGrpcTransport,
)

__all__ = ["BrandSuggestionServiceTransport", "BrandSuggestionServiceGrpcTransport"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v17.resources.types.customer_sk_ad_network_conversion_value_schema import (
    CustomerSkAdNetworkConversionValueSchema,
)

_M = TypeVar("_M")

class CustomerSkAdNetworkConversionValueSchemaOperation(proto.Message):
    update: CustomerSkAdNetworkConversionValueSchema
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        update: CustomerSkAdNetworkConversionValueSchema = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["update"]
    ) -> bool: ...

class MutateCustomerSkAdNetworkConversionValueSchemaRequest(proto.Message):
    customer_id: str
    operation: CustomerSkAdNetworkConversionValueSchemaOperation
    validate_only: bool
    enable_warnings: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operation: CustomerSkAdNetworkConversionValueSchemaOperation = ...,
        validate_only: bool = ...,
        enable_warnings: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["customer_id", "operation", "validate_only", "enable_warnings"],
    ) -> bool: ...

class MutateCustomerSkAdNetworkConversionValueSchemaResponse(proto.Message):
    result: MutateCustomerSkAdNetworkConversionValueSchemaResult
    warning: Status
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        result: MutateCustomerSkAdNetworkConversionValueSchemaResult = ...,
        warning: Status = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["result", "warning"]
    ) -> bool: ...

class MutateCustomerSkAdNetworkConversionValueSchemaResult(proto.Message):
    resource_name: str
    app_id: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        app_id: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name", "app_id"]
    ) -> bool: ...



from .base import (
    KeywordPlanCampaignKeywordServiceTransport as KeywordPlanCampaignKeywordServiceTransport,
)
from .grpc import (
    KeywordPlanCampaignKeywordServiceGrpcTransport as KeywordPlanCampaignKeywordServiceGrpcTransport,
)

__all__ = [
    "KeywordPlanCampaignKeywordServiceTransport",
    "KeywordPlanCampaignKeywordServiceGrpcTransport",
]



from .base import AccountLinkServiceTransport as AccountLinkServiceTransport
from .grpc import AccountLinkServiceGrpcTransport as AccountLinkServiceGrpcTransport

__all__ = ["AccountLinkServiceTransport", "AccountLinkServiceGrpcTransport"]



from .base import (
    AdGroupCriterionLabelServiceTransport as AdGroupCriterionLabelServiceTransport,
)
from .grpc import (
    AdGroupCriterionLabelServiceGrpcTransport as AdGroupCriterionLabelServiceGrpcTransport,
)

__all__ = [
    "AdGroupCriterionLabelServiceTransport",
    "AdGroupCriterionLabelServiceGrpcTransport",
]



from .base import ExtensionFeedItemServiceTransport as ExtensionFeedItemServiceTransport
from .grpc import (
    ExtensionFeedItemServiceGrpcTransport as ExtensionFeedItemServiceGrpcTransport,
)

__all__ = ["ExtensionFeedItemServiceTransport", "ExtensionFeedItemServiceGrpcTransport"]



from .base import AssetGroupServiceTransport as AssetGroupServiceTransport
from .grpc import AssetGroupServiceGrpcTransport as AssetGroupServiceGrpcTransport

__all__ = ["AssetGroupServiceTransport", "AssetGroupServiceGrpcTransport"]



import abc
from typing import Awaitable, Callable, Sequence

from _typeshed import Incomplete
from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v16.services.types import product_link_invitation_service

__all__ = ["ProductLinkInvitationServiceTransport"]

class ProductLinkInvitationServiceTransport(abc.ABC):
    AUTH_SCOPES: Incomplete
    DEFAULT_HOST: str
    def __init__(
        self,
        *,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        quota_project_id: str | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
        always_use_jwt_access: bool | None = False,
        **kwargs,
    ) -> None: ...
    def close(self) -> None: ...
    @property
    def create_product_link_invitation(
        self,
    ) -> Callable[
        [product_link_invitation_service.CreateProductLinkInvitationRequest],
        product_link_invitation_service.CreateProductLinkInvitationResponse
        | Awaitable[
            product_link_invitation_service.CreateProductLinkInvitationResponse
        ],
    ]: ...
    @property
    def update_product_link_invitation(
        self,
    ) -> Callable[
        [product_link_invitation_service.UpdateProductLinkInvitationRequest],
        product_link_invitation_service.UpdateProductLinkInvitationResponse
        | Awaitable[
            product_link_invitation_service.UpdateProductLinkInvitationResponse
        ],
    ]: ...
    @property
    def remove_product_link_invitation(
        self,
    ) -> Callable[
        [product_link_invitation_service.RemoveProductLinkInvitationRequest],
        product_link_invitation_service.RemoveProductLinkInvitationResponse
        | Awaitable[
            product_link_invitation_service.RemoveProductLinkInvitationResponse
        ],
    ]: ...
